FileTool

Struct FileTool 

pub struct FileTool;
File utility wrapper

Implementations

Source

impl FileTool

pub fn read_string<P: AsRef<Path>>(&self, path: P) -> Result<String>

Read the entire contents of a file into a string

pub fn read_bytes<P: AsRef<Path>>(&self, path: P) -> Result<Vec<u8>>

Read the entire contents of a file into a bytes vector

pub fn write_string<P: AsRef<Path>, C: AsRef<[u8]>>( &self, path: P, content: C, ) -> Result<()>

Write a string to a file (creates or overwrites)

pub fn exists<P: AsRef<Path>>(&self, path: P) -> bool

Check if a path exists

pub fn is_file<P: AsRef<Path>>(&self, path: P) -> bool

Check if a path is a file

pub fn is_dir<P: AsRef<Path>>(&self, path: P) -> bool

Check if a path is a directory

pub fn mkdir<P: AsRef<Path>>(&self, path: P) -> Result<()>

Create a single directory (fails if parent doesn’t exist)

pub fn mkdir_all<P: AsRef<Path>>(&self, path: P) -> Result<()>

Recursively create a directory and all of its parent components if they are missing

pub fn delete_file<P: AsRef<Path>>(&self, path: P) -> Result<()>

Delete a file

pub fn delete_dir<P: AsRef<Path>>(&self, path: P) -> Result<()>

Delete an empty directory

pub fn delete_recursive<P: AsRef<Path>>(&self, path: P) -> Result<()>

Recursively delete a directory and all of its contents

pub fn copy<P: AsRef<Path>, Q: AsRef<Path>>( &self, from: P, to: Q, ) -> Result<u64>

Copy a file

pub fn rename<P: AsRef<Path>, Q: AsRef<Path>>( &self, from: P, to: Q, ) -> Result<()>

Rename or move a file/directory

pub fn list_files<P: AsRef<Path>>(&self, dir: P) -> Result<Vec<PathBuf>>

List only files in a directory (non-recursive)

pub fn list_dirs<P: AsRef<Path>>(&self, dir: P) -> Result<Vec<PathBuf>>

List only directories in a directory (non-recursive)